--
--  Schema for storing Java objects according to RFC 2713
--
javaId			OBJECT-IDENTIFIER	::= { 1 3 6 1 4 1 42 2 27 4 }
--
--
javaAttributeType	OBJECT-IDENTIFIER	::= { javaId 1 }
javaObjectClass		OBJECT-IDENTIFIER	::= { javaId 2 }
javaForm		OBJECT-IDENTIFIER	::= { javaId 3 }
--
--  Attribute definitions according to RFC 2713
--
javaClassName	ATTRIBUTE
		WITH ATTRIBUTE-SYNTAX stringSyntax
		EQUALITY MATCHING RULE caseExactStringMatch
		SINGLE VALUED
		STORE NORMALIZED
		::= { javaAttributeType 6 }
--
javaCodeBase	ATTRIBUTE
		WITH ATTRIBUTE-SYNTAX iA5StringSyntax
		EQUALITY MATCHING RULE caseExactIA5StringMatch
		STORE NORMALIZED
		::= { javaAttributeType 7 }
--
--			WITH ATTRIBUTE-SYNTAX stringSyntax
--			WITH ATTRIBUTE-SYNTAX undefinedSyntax
javaSerializedData	ATTRIBUTE
			WITH ATTRIBUTE-SYNTAX octetStringSyntax
			SINGLE VALUED
			::= { javaAttributeType 8 }
--
javaFactory	ATTRIBUTE
		WITH ATTRIBUTE-SYNTAX stringSyntax
		EQUALITY MATCHING RULE caseExactStringMatch
		SINGLE VALUED
		STORE NORMALIZED
		::= { javaAttributeType 10 }
--
javaReferenceAddress	ATTRIBUTE
			WITH ATTRIBUTE-SYNTAX stringSyntax
			EQUALITY MATCHING RULE caseExactStringMatch
			STORE NORMALIZED
			::= { javaAttributeType 11 }
--
javaDoc		ATTRIBUTE
		WITH ATTRIBUTE-SYNTAX iA5StringSyntax
		EQUALITY MATCHING RULE caseExactIA5StringMatch
		STORE NORMALIZED
		::= { javaAttributeType 12 }
--
javaClassNames	ATTRIBUTE
		WITH ATTRIBUTE-SYNTAX stringSyntax
		EQUALITY MATCHING RULE caseExactStringMatch
		STORE NORMALIZED
		::= { javaAttributeType 13 }
--
--  Object class definitions according to RFC 2713
--
javaContainer	OBJECT-CLASS SUBCLASS OF top STRUCTURAL
		MUST CONTAIN
			{
			commonName
			}
		::= { javaObjectClass 1 }
--
javaObject	OBJECT-CLASS SUBCLASS OF top ABSTRACT
		MUST CONTAIN
			{
			javaClassName
			}
		MAY CONTAIN
			{
			javaClassNames,
			javaCodeBase,
			javaDoc,
			description
			}
		::= { javaObjectClass 4 }
--
javaSerializedObject	OBJECT-CLASS SUBCLASS OF javaObject AUXILIARY
			MUST CONTAIN
				{
				javaSerializedData
				}
			::= { javaObjectClass 5 }
--
javaNamingReference	OBJECT-CLASS SUBCLASS OF javaObject AUXILIARY
			MAY CONTAIN
				{
				javaReferenceAddress,
				javaFactory
				}
			::= { javaObjectClass 7 }
--
javaMarshalledObject	OBJECT-CLASS SUBCLASS OF javaObject AUXILIARY
			MUST CONTAIN
				{
				javaSerializedData
				}
			::= { javaObjectClass 8 }
--
--	Structural rules
--
javaContainerForm	NAME-FORM
			NAMES javaContainer
			WITH ATTRIBUTES commonName
			AND OPTIONALLY javaClassName
			::= { javaForm 110 }
--
--	Structural rules defining where in the DS structure tree entries are allowed
--
--	Structural rule identifiers 0 - 10999 are reserved by Compaq ( more or less )
--
javaStructureRule STRUCTURE-RULE
	NAME FORM javaContainerForm
	SUPERIOR RULES
		localityStructureRule, localityRootStructureRule,
		organizationStructureRule, organizationRootStructureRule,
		organizationalUnitStructureRule,
		javaStructureRule
	::= 12011
--
-- Description definitions used by DXIM
--
LABEL	javaClassName
	KEYWORD	"javaClassName"
	MENU	"Java Class Name"
	DESCRIPTION "Fully qualified name of distinguished Java class or interface"
	END

LABEL	javaCodeBase
	KEYWORD	"javaCodeBase"
	MENU "Java Code Base"
	DESCRIPTION "URL(s) specifying the location of class definition"
	END

LABEL	javaSerializedData
	KEYWORD "javaSerializedData"
	MENU "Java Serialized Data"
	DESCRIPTION "Serialized form of Java object"
	END

LABEL	javaFactory
	KEYWORD "javaFactory"
	MENU "Java Factory"
	DESCRIPTION "Fully qualified Java class name of a JNDI object factory"
	END

LABEL	javaReferenceAddress
	KEYWORD "javaReferenceAddress"
	DESCRIPTION "Addresses associated with a JNDI Reference"
	END

LABEL	javaDoc
	KEYWORD "javaDoc"
	DESCRIPTION "The Java documentation for the class"
	END

LABEL	javaClassNames
	KEYWORD "javaClassNames"
	DESCRIPTION "Fully qualified Java class or interface name"
	END

LABEL	javaContainer
	KEYWORD "javaContainer"
	DESCRIPTION "Container for a Java object"
	END

LABEL	javaObject
	KEYWORD "javaObject"
	DESCRIPTION "Java object representation"
	END

LABEL	javaSerializedObject
	KEYWORD "javaSerializedObject"
	DESCRIPTION "Java serialized object"
	END

LABEL	javaNamingReference
	KEYWORD "javaNamingReference"
	DESCRIPTION "JNDI reference"
	END

LABEL	javaMarshalledObject
	KEYWORD "javaMarshalledObject"
	DESCRIPTION "Java marshalled object"
	END
